"use strict";
Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "getPluginsChain", {
  enumerable: true,
  get: function() {
    return getPluginsChain;
  }
});
const _utils = require("@modern-js/utils");
const _babelchain = require("./babel-chain");
const getPluginsChain = (option) => {
  const { runEnvironments, plugins: { import: babelPluginImport, transformRuntime, styledComponentsOptions, lodashOptions } = {}, useLegacyDecorators = true, type = "module", useTsLoader = false } = option;
  const chain = (0, _babelchain.createBabelChain)();
  if (runEnvironments === "node") {
    chain.plugin("babel-plugin-dynamic-import-node").use(require.resolve("../compiled/babel-plugin-dynamic-import-node"));
  }
  const { antd } = babelPluginImport || {
    antd: {
      libraryDirectory: "es"
    }
  };
  if (antd !== false) {
    const antdMajorVersion = (0, _utils.getAntdMajorVersion)(option.appDirectory);
    if (antdMajorVersion && antdMajorVersion < 5) {
      chain.plugin("babel-plugin-import").use(require.resolve("../compiled/babel-plugin-import"), [
        {
          libraryName: "antd",
          libraryDirectory: (antd === null || antd === void 0 ? void 0 : antd.libraryDirectory) || "es",
          style: true
        },
        "import-antd"
      ]);
    }
  }
  chain.plugin("babel-plugin-lodash").use(require.resolve("../compiled/babel-plugin-lodash"), [
    lodashOptions || {}
  ]);
  if (useTsLoader) {
    return chain;
  }
  chain.plugin("@babel/plugin-proposal-decorators").use(require.resolve("../compiled/@babel/plugin-proposal-decorators"), [
    useLegacyDecorators ? {
      // https://github.com/nicolo-ribaudo/legacy-decorators-migration-utility
      legacy: true
    } : {
      legacy: false,
      decoratorsBeforeExport: true
    }
  ]);
  chain.plugin("@babel/plugin-transform-runtime").use(require.resolve("@babel/plugin-transform-runtime"), [
    {
      // By default, babel assumes babel/runtime version 7.0.0-beta.0,
      // explicitly resolving to match the provided helper functions.
      // https://github.com/babel/babel/issues/10261
      version: require("@babel/runtime/package.json").version,
      regenerator: true,
      // https://babeljs.io/docs/en/babel-plugin-transform-runtime#useesmodules
      // We should turn this on once the lowest version of Node LTS
      // supports ES Modules.
      useESModules: type === "module",
      // Undocumented option that lets us encapsulate our runtime, ensuring
      // the correct version is used
      // https://github.com/babel/babel/blob/090c364a90fe73d36a30707fc612ce037bdbbb24/packages/babel-plugin-transform-runtime/src/index.js#L35-L42
      // absoluteRuntime: absoluteRuntimePath,
      helpers: false,
      ...transformRuntime || {}
    }
  ]);
  chain.plugin("@babel/plugin-proposal-export-default-from").use(require.resolve("../compiled/@babel/plugin-proposal-export-default-from"));
  chain.plugin("@babel/plugin-proposal-pipeline-operator").use(require.resolve("../compiled/@babel/plugin-proposal-pipeline-operator"), [
    {
      proposal: "minimal"
    }
  ]);
  chain.plugin("@babel/plugin-proposal-partial-application").use(require.resolve("../compiled/@babel/plugin-proposal-partial-application"));
  if (styledComponentsOptions !== false) {
    chain.plugin("babel-plugin-styled-components").use(require.resolve("../compiled/babel-plugin-styled-components"), [
      styledComponentsOptions || {},
      "styled-components"
    ]);
  }
  return chain;
};
